﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;

namespace HelpHelf.Classes
{
    public class CheckFields
    {
        /// <summary>
        /// Проверка полей для регистрации пользователя
        /// </summary>
        /// <param name="surname">Фамилия</param>
        /// <param name="name">Имя</param>
        /// <param name="login">Логин</param>
        /// <param name="password">Пароль</param>
        /// <returns>Поля заполнены (true), поля не заполнены (false)</returns>
        public static bool CheckUser(string surname, string name, string login, string password)
        {
            if (!string.IsNullOrWhiteSpace(surname))
            {
                if (!string.IsNullOrWhiteSpace(name))
                {
                    if (!string.IsNullOrWhiteSpace(login))
                    {
                        if (!string.IsNullOrWhiteSpace(password))
                        {
                            return true;
                        }
                        else
                        {
                            MessageBox.Show("Заполните Пароль!", "Ошибка", MessageBoxButton.OK, MessageBoxImage.Error);
                            return false;
                        }
                    }
                    else
                    {
                        MessageBox.Show("Заполните Логин!", "Ошибка", MessageBoxButton.OK, MessageBoxImage.Error);
                        return false;
                    }
                }
                else
                {
                    MessageBox.Show("Заполните Имя!", "Ошибка", MessageBoxButton.OK, MessageBoxImage.Error);
                    return false;
                }
            }
            else
            {
                MessageBox.Show("Заполните Фамилию!", "Ошибка", MessageBoxButton.OK, MessageBoxImage.Error);
                return false;
            }
        }

        /// <summary>
        /// Проверка полей при авторизации
        /// </summary>
        /// <param name="login">Логин</param>
        /// <param name="password">Пароль</param>
        /// <returns>Поля заполнены (true), поля не заполнены (false)</returns>
        public static bool CheckAuthorization(string login, string password)
        {
            if (!string.IsNullOrWhiteSpace(login))
            {
                if (!string.IsNullOrEmpty(password))
                {
                    return true;
                }
                else
                {
                    MessageBox.Show("Заполните Пароль", "Ошибка", MessageBoxButton.OK, MessageBoxImage.Error);
                    return false;
                }
            }
            else
            {
                MessageBox.Show("Заполните Логин", "Ошибка", MessageBoxButton.OK, MessageBoxImage.Error);
                return false;
            }
        }

        /// <summary>
        /// Проверка повторяющихся логинов при регистрации
        /// </summary>
        /// <param name="login">Логин</param>
        /// <returns>Поля заполнены (true), поля не заполнены (false)</returns>
        public static bool CheckLogin(string login, LoginedTable loginedTable)
        {
            LoginedTable logined;
            if(loginedTable == null)
            {
                logined = Classes.DateBase.connect.LoginedTable.FirstOrDefault(x => x.Login == login);
            }
            else
            {
                logined = Classes.DateBase.connect.LoginedTable.FirstOrDefault(x => x.Login == login && x.ID == loginedTable.ID);
            }
            if(logined == null)
            {
                return true;
            }
            else
            {
                MessageBox.Show("Такой Логин уже занят", "Ошибка", MessageBoxButton.OK, MessageBoxImage.Error);
                return false;
            }
        }

        /// <summary>
        /// Проверка на совподения повтора пароля при изменении
        /// </summary>
        /// <param name="password">Пароль</param>
        /// <param name="repeat">Старый пароль</param>
        /// <returns>Пароли совпвдают (true), пароли не совпвдают (false)</returns>
        public static bool CheckRepeatePassword(string password, string repeat)
        {
            if(password == repeat)
            {
                return true;
            }
            else
            {
                MessageBox.Show("Пароли не совпадают", "Ошибка", MessageBoxButton.OK, MessageBoxImage.Error);
                return false;
            }
        }

        /// <summary>
        /// Проверка пароля в бд
        /// </summary>
        /// <param name="password">Пароль</param>
        /// <param name="logined">Пользователь</param>
        /// <returns>Пароль совадает (true), пароль не совпвдает (false)</returns>
        public static bool CheckOldPassword(string password, LoginedTable logined)
        {
            int passw = password.GetHashCode();// шифровка введенных данных для проверки с бд
            if(passw == logined.Password)
            {
                return true;
            }
            else
            {
                MessageBox.Show("Старый Пароль не верный", "Ошибка", MessageBoxButton.OK, MessageBoxImage.Error);
                return false;
            }
        }

        /// <summary>
        /// Проверка полей для изменения данных пользователя
        /// </summary>
        /// <param name="surname">Фамилия</param>
        /// <param name="name">Имя</param>
        /// <param name="login">Логин</param>
        /// <returns>Поля заполнены (true), поля не заполнены (false)</returns>
        public static bool CheckUpdateUser(string surname, string name, string login)
        {
            if(!string.IsNullOrEmpty(surname))
            {
                if(!string.IsNullOrEmpty(name))
                {
                    if(!string.IsNullOrEmpty(login))
                    {
                        return true;
                    }
                    else
                    {
                        MessageBox.Show("Заполните Логин", "Ошибка", MessageBoxButton.OK, MessageBoxImage.Error);
                        return false;
                    }
                }
                else
                {
                    MessageBox.Show("Заполните Имя", "Ошибка", MessageBoxButton.OK, MessageBoxImage.Error);
                    return false;
                }
            }
            else
            {
                MessageBox.Show("Заполните Фамилию", "Ошибка", MessageBoxButton.OK, MessageBoxImage.Error);
                return false;
            }
        }

        /// <summary>
        /// Проверка полей для смены пароля
        /// </summary>
        /// <param name="oldPassword">Старый пароль</param>
        /// <param name="newPassword">Новый пароль</param>
        /// <param name="repeatPassword">Повтор</param>
        /// <returns>Поля заполнены (true), поля не заполнены (false)</returns>
        public static bool CheckUpdatePassword(string oldPassword, string newPassword, string repeatPassword)
        {
            if (!string.IsNullOrEmpty(oldPassword))
            {
                if (!string.IsNullOrEmpty(newPassword))
                {
                    if (!string.IsNullOrEmpty(repeatPassword))
                    {
                        return true;
                    }
                    else
                    {
                        MessageBox.Show("Неверный повтор пароля", "Ошибка", MessageBoxButton.OK, MessageBoxImage.Error);
                        return false;
                    }
                }
                else
                {
                    MessageBox.Show("Введите новый пароль", "Ошибка", MessageBoxButton.OK, MessageBoxImage.Error);
                    return false;
                }
            }
            else
            {
                MessageBox.Show("Введите старый пароль", "Ошибка", MessageBoxButton.OK, MessageBoxImage.Error);
                return false;
            }
        }

        /// <summary>
        /// Проверка наличия ответов
        /// </summary>
        /// <param name="answerList">Лист с ответами</param>
        /// <returns>Выбраны все ответы (true), выбраны не все ответы (false)</returns>
        public static bool CheckAnswer(List<Classes.AnswerClass> answerList)
        {
            int a = 0;
            foreach (Classes.AnswerClass answer in answerList)
            {
                if(answer.Aswer==0)
                {
                    a++;
                }
            }
            if(a==0)
            {
                return true;
            }
            else
            {
                MessageBox.Show("Заполните все ответы","Ошибка", MessageBoxButton.OK, MessageBoxImage.Error);
                return false;
            }
        }
    }
}
