﻿using Microsoft.VisualStudio.TestTools.UnitTesting;
using HelpHelf;
using HelpHelf.Classes;
using System;

namespace UnitTestHelpHelf
{
    [TestClass]
    public class UnitTest1
    {
        /// <summary>
        /// Положительный тест на проверку полей для регистрации пользователя
        /// </summary>
        [TestMethod]
        public void CheckUser_IsTrue()
        {
            Assert.IsTrue(CheckFields.CheckUser("Иванов","Иван", "admin", "admin"));//при правильном заполнении полей для регистрации результатом теста будет являться "true"
        }

        /// <summary>
        /// Негативный тест на проверку полей для регистрации пользователя
        /// </summary>
        [TestMethod]
        public void CheckUser_IsFalse()
        {
            Assert.IsFalse(CheckFields.CheckUser("Иванов", "Иван", "admin", ""));//при одном не заполненном поле для регистрации результатом теста будет являться "false"
        }

        /// <summary>
        /// Положительный тест на проверку автоизации
        /// </summary>
        [TestMethod]
        public void CheckAuthorization_IsTrue()
        {
            Assert.IsTrue(CheckFields.CheckAuthorization("admin", "admin"));//при правильном заполнении полей для авторизации результатом теста будет являться "true"
        }

        /// <summary>
        /// Негативный тест на проверку автоизации
        /// </summary>
        [TestMethod]
        public void CheckAuthorization_IsFalse()
        {
            Assert.IsFalse(CheckFields.CheckAuthorization("admin", ""));//при одном не заполненном поле для авторизации результатом теста будет являться "false"
        }

        /// <summary>
        /// Положительный тест на проверку повтора пароля
        /// </summary>
        [TestMethod]
        public void CheckRepeatePassword_IsTrue()
        {
            Assert.IsTrue(CheckFields.CheckRepeatePassword("admin", "admin"));//при правильном заполнении полей для повтора пароля результатом теста будет являться "true"
        }

        /// <summary>
        /// Негативный тест на проверку автоизации
        /// </summary>
        [TestMethod]
        public void CheckRepeatePassword_IsFalse()
        {
            Assert.IsFalse(CheckFields.CheckRepeatePassword("admin", "aadmin"));//при неправильном повторении пароля будет выводиться резульат "false"
        }

        /// <summary>
        /// Положительный тест на проверку старого пароля
        /// </summary>
        [TestMethod]
        public void CheckOldPassword_IsTrue()
        {
            Assert.IsTrue(CheckFields.CheckOldPassword("admin", new LoginedTable() {ID = 1, Login = "admin", Password = "admin".GetHashCode()}));//при правильном введении старого пароля будет выводиться результат "true"
        }


        /// <summary>
        /// Негативный тест на проверку старого пароля
        /// </summary>
        [TestMethod]
        public void CheckOldPassword_IsFalse()
        {
            Assert.IsFalse(CheckFields.CheckOldPassword("admin", new LoginedTable() { ID = 1, Login = "admin", Password = "aadmin".GetHashCode() }));//при не правильном введении старого пароля будет выводиться результат "false"
        }

        /// <summary>
        /// Положительный тест на проверку полей для изменения данных пользователя
        /// </summary>
        [TestMethod]
        public void CheckUpdateUser_IsTrue()
        {
            Assert.IsTrue(CheckFields.CheckUpdateUser("Иванов","Иван","admin"));//при правильном заполнении полей для изменении данных пользователя результатом теста будет являться "true"
        }

        /// <summary>
        /// Негативный тест на проверку полей для изменения данных пользователя
        /// </summary>
        [TestMethod]
        public void CheckUpdateUser_IsFalse()
        {
            Assert.IsFalse(CheckFields.CheckUpdateUser("Иванов", "Иван", ""));//при не заполненном поле для изменения данных пользователя результатом теста будет являться "false"
        }

        /// <summary>
        /// Положительный тест на проверку полей для смены пароля
        /// </summary>
        [TestMethod]
        public void CheckUpdatePassword_IsTrue()
        {
            Assert.IsTrue(CheckFields.CheckUpdatePassword("admin", "admin11", "admin11"));//при правильном заполнении полей для изменении пароля пользователя результатом теста будет являться "true"
        }

        /// <summary>
        /// Негативный тест на проверку полей для смены пароля
        /// </summary>
        [TestMethod]
        public void CheckUpdatePassword_IsFalse()
        {
            Assert.IsFalse(CheckFields.CheckUpdatePassword("", "admin11", "admin11"));//при не заполненном поле для изменения пароля пользователя результатом теста будет являться "false"
        }

        /// <summary>
        /// Положительный тест на проверку выбора ответов
        /// </summary>
        [TestMethod]
        public void CheckAnswer_IsTrue()
        {
            Assert.IsTrue(CheckFields.CheckAnswer(new System.Collections.Generic.List<AnswerClass>() 
            {
                new AnswerClass() {Question = 1, Aswer = 1},
                new AnswerClass() {Question = 2, Aswer = 2},
                new AnswerClass() {Question = 3, Aswer = 3},
                new AnswerClass() {Question = 4, Aswer = 4},
            })); // при правильных ответах в тестировании результатом будет являться "true"
        }

        /// <summary>
        /// Негативный тест на проверку выбора ответов
        /// </summary>
        [TestMethod]
        public void CheckAnswer_IsFalse()
        {
            Assert.IsFalse(CheckFields.CheckAnswer(new System.Collections.Generic.List<AnswerClass>() 
            {
                new AnswerClass() {Question = 1, Aswer = 1},
                new AnswerClass() {Question = 2, Aswer = 0},
                new AnswerClass() {Question = 3, Aswer = 3},
                new AnswerClass() {Question = 4, Aswer = 0},
            })); // при не правильнрых или не заполненных ответах в тестировании результатом будет являться "false"
        }
    }
}
